# Motivation

```{include} ../../README.md
:start-after: '<!-- docs-motivation-begin -->'
:end-before: '<!-- docs-motivation-end -->'
```

See the [ROADMAP](./roadmap.md) for planned features and future direction of django-bird.
